summaryrefslogtreecommitdiff
path: root/keystoneclient/auth
diff options
context:
space:
mode:
authorDolph Mathews <dolph.mathews@gmail.com>2015-10-21 15:37:18 +0000
committerDolph Mathews <dolph.mathews@gmail.com>2015-10-21 15:37:18 +0000
commitb588609a06abb91691e3caeb14c3a474b7aadb5c (patch)
treec9cdbe4ea73727d6faf6ef96f209ac171ac60e9d /keystoneclient/auth
parent6588ad5fb5a3162aa2204ca38fb5a89a1f940985 (diff)
downloadpython-keystoneclient-b588609a06abb91691e3caeb14c3a474b7aadb5c.tar.gz
Docstring spelling and function-vs-method fixes
These are all object methods, not independent functions. Change-Id: I3c232d922e61a94c7dc2c2b9a8d3768fd42be1a7
Diffstat (limited to 'keystoneclient/auth')
-rw-r--r--keystoneclient/auth/identity/base.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/keystoneclient/auth/identity/base.py b/keystoneclient/auth/identity/base.py
index 02c4fe6..b8ac1c4 100644
--- a/keystoneclient/auth/identity/base.py
+++ b/keystoneclient/auth/identity/base.py
@@ -164,13 +164,13 @@ class BaseIdentityPlugin(base.BaseAuthPlugin):
This method is overridden by the various token version plugins.
- This function should not be called independently and is expected to be
- invoked via the do_authenticate function.
+ This method should not be called independently and is expected to be
+ invoked via the do_authenticate() method.
- This function will be invoked if the AcessInfo object cached by the
+ This method will be invoked if the AccessInfo object cached by the
plugin is not valid. Thus plugins should always fetch a new AccessInfo
- when invoked. If you are looking to just retrieve the current auth
- data then you should use get_access.
+ when invoked. If you are looking to just retrieve the current auth data
+ then you should use get_access().
:param session: A session object that can be used for communication.
:type session: keystoneclient.session.Session